pub(crate) fn compute_average_batch_size(
estimated_rows_per_batch: impl IntoIterator<Item = usize>,
) -> usizeExpand description
Computes the average estimated rows per batch across multiple range readers.
pub(crate) fn compute_average_batch_size(
estimated_rows_per_batch: impl IntoIterator<Item = usize>,
) -> usizeComputes the average estimated rows per batch across multiple range readers.