should_split_flat_batches_for_merge

Function should_split_flat_batches_for_merge 

pub(crate) fn should_split_flat_batches_for_merge(
    stream_ctx: &Arc<StreamContext>,
    range_meta: &RangeMeta,
) -> Option<usize>
Returns the estimated rows per batch after splitting if splitting flat record batches may improve merge performance. Returns None if splitting is not beneficial.